@@ -10,8 +10,10 @@ from drkns.runner.get_successful_flag_and_combined_output import\
 def run(
         root_config_unit: ConfigUnit,
         target_step_name: Optional[str] = None,
-        summary: bool = False) \
+        summary: bool = False,
+        limit_output: bool = False) \
         -> Tuple[int, List[str]]:
     plan = get_execution_plan(root_config_unit, target_step_name)
     status_history = run_plan(plan)
-    return get_successful_flag_and_combined_output(status_history, summary)
+    return get_successful_flag_and_combined_output(
+        status_history, summary, limit_output)
